// AuxiliaryMethods.cpp : implementation file
//

#include "stdafx.h"
#include "Common.h"
#include "Helper.h"
#include "DataSources.h"
#include "DataSourcesDlg.h"

void CDataSourcesDlg::InitializeCQGCEL()
{
   // Create an instance of CQG API
   HRESULT hr = m_spCQGCEL.CoCreateInstance(__uuidof(CQGCEL), NULL, CLSCTX_INPROC_SERVER);
   Common::ThrowOnCOMError(m_spCQGCEL, hr);

   // Configure CQGCEL behavior
   ATL::CComPtr<ICQGAPIConfig> spConf;
   hr = m_spCQGCEL->get_APIConfiguration(&spConf);
   Common::ThrowOnCOMError(m_spCQGCEL, hr);

   hr = spConf->put_ReadyStatusCheck(rscOff);
   Common::ThrowOnCOMError(spConf, hr);

   hr = spConf->put_UsedFromATLClient(VARIANT_TRUE);
   Common::ThrowOnCOMError(spConf, hr);

   hr = spConf->put_CollectionsThrowException(VARIANT_FALSE);
   Common::ThrowOnCOMError(spConf, hr);

   hr = spConf->put_TimeZoneCode(tzCentral);
   Common::ThrowOnCOMError(spConf, hr);

   // Now advise the connection, to get events
   hr = ICQGCELDispEventImpl::DispEventAdvise(m_spCQGCEL);
   ATLASSERT(SUCCEEDED(hr));

   hr = m_spCQGCEL->Startup();
   Common::ThrowOnCOMError(m_spCQGCEL, hr);
}

void CDataSourcesDlg::InitializeControls()
{
   ClearDataSources();
   ClearDataSourceSymbols();

   EnableControls();
}

void CDataSourcesDlg::ClearDataSources()
{
   m_spDataSources = NULL;
   m_cmbDSAbbreviation.ResetContent();

   ClearDataSource();
}

void CDataSourcesDlg::ClearDataSource()
{
   m_lblDSName.SetWindowText(_T(""));
   m_lblDSStatus.SetWindowText(_T(""));
   m_lblDSSymbolTypes.SetWindowText(_T(""));
   m_edDSAbbreviation.SetWindowText(_T(""));
}

void CDataSourcesDlg::ClearDataSourceSymbols()
{
   m_spDataSourceSymbols = NULL;

   m_cmbDSSAbbreviation.ResetContent();
   m_lblDSSDSAbbreviation.SetWindowText(_T(""));

   ClearDataSourceSymbol();
}

void CDataSourcesDlg::ClearDataSourceSymbol()
{
   m_lblDSSDescription.SetWindowText(_T(""));
   m_lblDSSType.SetWindowText(_T(""));
}

void CDataSourcesDlg::EnableControls()
{
   bool isDataConnectionUp = false;

   VARIANT_BOOL isStarted;
   HRESULT hr = m_spCQGCEL->get_IsStarted(&isStarted);
   Common::ThrowOnCOMError(m_spCQGCEL, hr);

   if (isStarted)
   {
      ATL::CComPtr<ICQGEnvironment> spEnvironment;
      hr = m_spCQGCEL->get_Environment(&spEnvironment);
      Common::ThrowOnCOMError(m_spCQGCEL, hr);

      eConnectionStatus dataConnectionStatus;
      hr = spEnvironment->get_DataConnectionStatus(&dataConnectionStatus);
      Common::ThrowOnCOMError(spEnvironment, hr);

      isDataConnectionUp = (dataConnectionStatus == csConnectionUp);
   }

   m_btnRequestDS.EnableWindow(isDataConnectionUp);

   CString dsAbbreviation;
   m_edDSAbbreviation.GetWindowText(dsAbbreviation);
   bool isDataSourcesSelected = !dsAbbreviation.IsEmpty();

   m_btnRequestDSS.EnableWindow(isDataConnectionUp && isDataSourcesSelected);
}
